gimp r24678 - in trunk: . app/paint



Author: neo
Date: Tue Jan 22 20:20:02 2008
New Revision: 24678
URL: http://svn.gnome.org/viewvc/gimp?rev=24678&view=rev

Log:
2008-01-22  Sven Neumann  <sven gimp org>

	* app/paint/gimpbrushcore.c (gimp_brush_core_create_bound_segs):
	smooth the mask instead of dilating.



Modified:
   trunk/ChangeLog
   trunk/app/paint/gimpbrushcore.c

Modified: trunk/app/paint/gimpbrushcore.c
==============================================================================
--- trunk/app/paint/gimpbrushcore.c	(original)
+++ trunk/app/paint/gimpbrushcore.c	Tue Jan 22 20:20:02 2008
@@ -786,8 +786,8 @@
       pixel_region_init_temp_buf (&PR, mask,
                                   0, 0, mask->width, mask->height);
 
-      /*  dilate the mask in order to obtain a simpler boundary  */
-      dilate_region (&PR);
+      /*  smooth the mask in order to obtain a simpler boundary  */
+      smooth_region (&PR);
 
       boundary = boundary_find (&PR, BOUNDARY_WITHIN_BOUNDS,
                                 0, 0, PR.w, PR.h,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]